# -*- rpm-spec -*-

# This macro is used for the continuous automated builds. It just
# allows an extra fragment based on the timestamp to be appended
# to the release. This distinguishes automated builds, from formal
# Fedora RPM builds
%define _extra_release %{?dist:%{dist}}%{!?dist:%{?extra_release:%{extra_release}}}

Name: virt-manager
Version: 0.6.1
Release: 12%{_extra_release}
Summary: Virtual Machine Manager

Group: Applications/Emulators
License: GPLv2+
URL: http://virt-manager.org/
Source0: http://virt-manager.org/download/sources/%{name}/%{name}-%{version}.tar.gz
Source1: %{name}.pam
Source2: %{name}.console

# Fix ctrl-alt-del and ctrl-alt-backspace
Patch1: %{name}-%{version}-fix-cadl.patch
# Fix recording gconf values for cpu and mem stats
Patch2: %{name}-%{version}-fix-stats-options.patch
# Don't overwrite VNC password when changing guest XML
Patch3: %{name}-%{version}-vnc-password-overwrite.patch
# Don't attempt to read disk and net stats if the VM is inactive, it can
# throw pointless error messages and is needless traffic
Patch4: %{name}-%{version}-inactive-stats.patch
# Use openAuth in every place we fork off a connection
Patch5: %{name}-%{version}-always-open-auth.patch
# Migration related fixes
Patch6: %{name}-%{version}-migrate-fixes.patch
# Fix handling of older libvirt style <console/> tag
Patch7: %{name}-%{version}-oldstyle-console.patch
# Don't show an error dialog if the user exits via the cli
Patch8: %{name}-%{version}-keyboard-error.patch
# Alter a VM's inactive config if adding/removing hardware (bug 479215)
Patch9: %{name}-%{version}-inactive-xml.patch
# Try to detect if libvirt version can handle dumpxml flags
Patch10: %{name}-%{version}-check-xml-flags.patch
# Don't show error in 'try_login' if VM is 'destroyed' (bug 436320)
Patch11: %{name}-%{version}-trylogin-error.patch
# Host device assignment UI
Patch12: %{name}-%{version}-hostdev-attach.patch
# Default scaling to off, so we maintain existing behavior
Patch13: %{name}-%{version}-default-scaling-off.patch
# Add pylint script (for devel purposes)
Patch14: %{name}-%{version}-pylint-script.patch
# Hide help buttons, since docs are so out of date (bz 443628, 460713)
Patch15: %{name}-%{version}-hide-help.patch
# Disable URL install option for Xen HVM (bz 504171)
Patch16: %{name}-%{version}-disable-xen-url.patch
# Enable hostdev assignment for xen (needed for rebase)
Patch17: %{name}-%{version}-enable-xen-hostdev.patch
# Fix traceback with --help (bz 507325)
Patch18: %{name}-%{version}-no-help-traceback.patch
# Fix screenshot response message (bz 508249)
Patch19: %{name}-%{version}-fix-screenshot-response.patch
# Fix issue where FV url install can be erroneously selected (bz 507207)
Patch20: %{name}-%{version}-fix-fv-url.patch
# Fix qemu availability detection on first run (bz 507437)
Patch21: %{name}-%{version}-fix-qemu-autodetect.patch
# Default to 'no sound device' for new VMs (bz 508751)
Patch22: %{name}-%{version}-default-no-sound.patch
# Fix migration for qemu/kvm (bz 509135)
Patch23: %{name}-%{version}-migrate-fixes2.patch
# Add supported OS URL when choosing os type/variant (bz 500927)
Patch24: %{name}-%{version}-supported-os-link.patch
# Use ac97 as only sound model for qemu driver (bz 506035)
Patch25: %{name}-%{version}-use-ac97.patch
# Add proper migrate dialog (bz 510702, bz 509985, bz 518487, bz 508357)
Patch26: %{name}-%{version}-migrate-dialog.patch
# Better error handling when creating networks (bz 508273)
Patch27: %{name}-%{version}-create-net-errors.patch
# Catch harmless tracebacks when connecting to VNC (bz 436320)
Patch28: %{name}-%{version}-catch-vnc-errors.patch
# Disable send key option when machine is paused (bz 509808)
Patch29: %{name}-%{version}-pause-send-key.patch
# Allow creating routed virtual networks (bz 452644)
Patch30: %{name}-%{version}-enable-routed-networking.patch
# Use URI port for remote VNC connection (bz 534005)
Patch31: %{name}-%{version}-vnc-ssh-port.patch
# Improve some UI accelerators and mnemonics (bz 509746)
Patch32: %{name}-%{version}-ui-mnemonics.patch
# Make hotplug operations persistent (bz 522096, bz 539496)
Patch33: %{name}-%{version}-make-hotplug-persistent.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

# These two are just the oldest version tested
Requires: pygtk2 >= 1.99.12-6
Requires: gnome-python2-gconf >= 1.99.11-7
# Absolutely require this version or newer
Requires: libvirt-python >= 0.3.3
# Definitely does not work with earlier due to python API changes
Requires: dbus-python >= 0.61
# Might work with earlier, but this is what we've tested
Requires: gnome-keyring >= 0.4.9
# Minimum we've tested with
# Although if you don't have this, comment it out and the app
# will work just fine - keyring functionality will simply be
# disabled
Requires: gnome-python2-gnomekeyring >= 2.15.4
# Minimum we've tested with
Requires: libxml2-python >= 2.6.23
# Required to install Xen guests
Requires: python-virtinst >= 0.400.3
# Required for loading the glade UI
Requires: pygtk2-libglade
# Required for our graphics which are currently SVG format
Requires: librsvg2
# Earlier vte had broken python binding module
Requires: vte >= 0.12.2
# For the consolehelper PAM stuff
Requires: usermode
# For online help
Requires: scrollkeeper
# For the guest console
Requires: gtk-vnc-python >= 0.3.8

ExclusiveArch: %{ix86} x86_64 ia64

BuildRequires: pygtk2-devel
BuildRequires: gtk2-devel
BuildRequires: pygobject2-devel
BuildRequires: glib2-devel
BuildRequires: python-devel
BuildRequires: pango-devel
BuildRequires: atk-devel
BuildRequires: cairo-devel
BuildRequires: gettext
BuildRequires: scrollkeeper
BuildRequires: intltool

Requires(pre): GConf2
Requires(post): GConf2
Requires(preun): GConf2
Requires(post): desktop-file-utils
Requires(postun): desktop-file-utils

%description
Virtual Machine Manager provides a graphical tool for administering virtual
machines for KVM, Xen, and QEmu. Start, stop, add or remove virtual devices,
connect to a graphical or serial console, and see resource usage statistics
for existing VMs on local or remote machines. Uses libvirt as the backend
management API.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
%patch25 -p1
%patch26 -p1
%patch27 -p1
%patch28 -p1
%patch29 -p1
%patch30 -p1
%patch31 -p1
%patch32 -p1
%patch33 -p1

%build
%configure
make %{?_smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT
make install  DESTDIR=$RPM_BUILD_ROOT
rm -f $RPM_BUILD_ROOT%{_libdir}/%{name}/sparkline.a
rm -f $RPM_BUILD_ROOT%{_libdir}/%{name}/sparkline.la

# Adjust for console-helper magic
mkdir -p $RPM_BUILD_ROOT%{_sbindir}
mv $RPM_BUILD_ROOT%{_bindir}/%{name} $RPM_BUILD_ROOT%{_sbindir}/%{name}
ln -s ../bin/consolehelper $RPM_BUILD_ROOT%{_bindir}/%{name}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/pam.d
cp %{SOURCE1} $RPM_BUILD_ROOT%{_sysconfdir}/pam.d/%{name}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/security/console.apps
cp %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/security/console.apps/%{name}

%find_lang %{name}

%clean
rm -rf $RPM_BUILD_ROOT

%pre
if [ "$1" -gt 1 ]; then
    export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
    gconftool-2 --makefile-uninstall-rule \
      %{_sysconfdir}/gconf/schemas/%{name}.schemas > /dev/null || :
fi

%post
export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
gconftool-2 --makefile-install-rule \
  %{_sysconfdir}/gconf/schemas/%{name}.schemas > /dev/null || :

update-desktop-database %{_datadir}/applications

if which scrollkeeper-update>/dev/null 2>&1; then scrollkeeper-update -q -o %{_datadir}/omf/%{name}; fi

%postun
update-desktop-database %{_datadir}/applications

if which scrollkeeper-update>/dev/null 2>&1; then scrollkeeper-update -q; fi

%preun
if [ "$1" -eq 0 ]; then
    export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
    gconftool-2 --makefile-uninstall-rule \
      %{_sysconfdir}/gconf/schemas/%{name}.schemas > /dev/null || :
fi

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc README COPYING COPYING-DOCS AUTHORS ChangeLog NEWS
%{_sysconfdir}/gconf/schemas/%{name}.schemas
%config(noreplace) %{_sysconfdir}/pam.d/%{name}
%{_sysconfdir}/security/console.apps/%{name}
%{_bindir}/%{name}
%{_sbindir}/%{name}
%{_libexecdir}/%{name}-launch
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/*

%{_mandir}/man1/%{name}.1*

%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/*.glade
%{_datadir}/%{name}/*.py
%{_datadir}/%{name}/*.pyc
%{_datadir}/%{name}/*.pyo

%dir %{_datadir}/%{name}/pixmaps/
%{_datadir}/%{name}/pixmaps/*.png
%{_datadir}/%{name}/pixmaps/*.svg

%dir %{_datadir}/%{name}/virtManager/
%{_datadir}/%{name}/virtManager/*.py
%{_datadir}/%{name}/virtManager/*.pyc
%{_datadir}/%{name}/virtManager/*.pyo

%{_datadir}/omf/%{name}/
%{_datadir}/gnome/help/%{name}/

%{_datadir}/applications/%{name}.desktop
%{_datadir}/dbus-1/services/%{name}.service

%changelog
* Wed Jan  6 2010 Cole Robinson <crobinso@redhat.com> - 0.6.1-12.el5
- Fix accessing migrate dialog from VM details (bz 510702)
- Actually fix VNC access over TCP URI with port specified (bz 534005)

* Mon Dec 21 2009 Cole Robinson <crobinso@redhat.com> - 0.6.1-11.el5
- Actually apply patch for previous build

* Tue Dec 15 2009 Cole Robinson <crobinso@redhat.com> - 0.6.1-10.el5
- Make hotplug operations persistent (bz 522096, bz 539496)

* Tue Dec 15 2009 Cole Robinson <crobinso@redhat.com> - 0.6.1-9.el5
- Add proper migrate dialog (bz 510702, bz 509985, bz 518487, bz 508357)
- Better error handling when creating networks (bz 508273)
- Use URI port for remote VNC connection (bz 534005)
- Disable send key option when machine is paused (bz 509808)
- Allow creating routed virtual networks (bz 452644)
- Catch harmless tracebacks when connecting to VNC (bz 436320)
- Improve some UI accelerators and mnemonics (bz 509746)

* Wed Jul 29 2009 Cole Robinson <crobinso@redhat.com> - 0.6.1-8.el5
- Fix supported OS URL to actually launch a web browser (bz 500927)

* Tue Jul 14 2009 Cole Robinson <crobinso@redhat.com> - 0.6.1-7.el5
- Add supported OS URL when choosing os type/variant (bz 500927)
- Use ac97 as only sound model for qemu driver (bz 506035)

* Mon Jun 29 2009 Cole Robinson <crobinso@redhat.com> - 0.6.1-6.el5
- Fix screenshot response message (bz 508249)
- Fix issue where FV url install can be erroneously selected (bz 507207)
- Fix qemu availability detection on first run (bz 507437)
- Default to 'no sound device' for new VMs (bz 508751)
- Fix migration for qemu/kvm (bz 509135)

* Mon Jun 29 2009 Cole Robinson <crobinso@redhat.com> - 0.6.1-5.el5
- Fix traceback when run with --help (bz 507325)
- Hide help in preferences section (part of 443628, 448716, 460713)

* Mon Jun 22 2009 Cole Robinson <crobinso@redhat.com> - 0.6.1-4.el5
- Enable hostdev assignment for xen (needed for rebase bz 489374)

* Mon Jun  8 2009 Cole Robinson <crobinso@redhat.com> - 0.6.1-3.el5
- Hide out of date docs (bz 443628, 448716, 460713)
- Disable xen hvm URL install option (bz 504171)

* Thu Apr 23 2009 Cole Robinson <crobinso@redhat.com> - 0.6.1-2.el5
- Bump gtk-vnc dependency to 0.3.8 (needed for rebase bz 489374)

* Mon Mar 16 2009 Cole Robinson <crobinso@redhat.com> - 0.6.1-1.el5
- Rebase to version 0.6.1 (bz 489374)

* Fri Sep 19 2008 Cole Robinson <crobinso@redhat.com> - 0.5.3-10.el5
- Allow specifying a keymap when adding a vnc graphics device (bz 251431)
- Try to determine block devices sizes, print '-' otherwise (bz 453061)
- Show 'help' in host dialog, not 'about' (bz 443604)
- Don't default to selecting invalid bridge device (bz 446498)
- Desensitive 'Add Network' button if not connected to hypervisor (bz 457878)
- Fix command line options (bz 441841)
- Reconnect with open serial console after VM restart (bz 248973)

* Sun Sep 14 2008 Cole Robinson <crobinso@redhat.com> - 0.5.3-9.el5
- Allow using bridges on bonding or vlan devices (bz 447412)
- Fix memory leak (bz 443680)
- Don't squash user input disk size if moving back in the wizard (bz 452468)
- Use 'xen:///' instead of 'xen' for connect dialog URI (bz 441850)
- Trim URL and KS input text (bz 437514)
- Hitting enter in file chooser should select active file (bz 298771)
- Allow setting maxmem lower than current allocation (bz 428868)
- Allow setting maxmem and current mem simultaneously (bz 428867)

* Tue Apr  22 2008 Cole Robinson <crobinso@redhat.com> - 0.5.3-8.el5
- Fix delete button sensitivity when shutting down a selected guest (bz 427545)
- Throw error when install location is empty (bz 442697)
- Another fix for removing a cdrom with a driver tag (bz 437174)

* Tue Apr  8 2008 Cole Robinson <crobinso@redhat.com> - 0.5.3-7.el5
- Catch empty cdrom patch in create wizard (rhbz #440638)
- Don't print bogus disk size in create summary for block dev (rhbz #440245)

* Tue Apr  1 2008 Daniel P. Berrange <berrange@redhat.com> - 0.5.3-6.el5
- Fix sending of C-A-D  keysequence (rhbz #439394)

* Tue Mar 18 2008 Cole Robinson <crobinso@redhat.com> - 0.5.3-5.el5
- Fix cdrom media connect (rhbz #437174)

* Thu Mar  6 2008 Daniel P. Berrange <berrange@redhat.com> - 0.5.3-4.el5
- Fix default Xen hypervisor URI (rhbz #435879)

* Thu Mar  6 2008 Daniel P. Berrange <berrange@redhat.com> - 0.5.3-3.el5
- Fix DBus calls to use an explicit interface (rhbz #436276)

* Mon Feb 4 2008 Cole Robinson <crobinso@redhat.com> - 0.5.3-2.el5
- Fix adding blktap disk to PV guest via addhardware wizard (rhbz #430930)
- Fix adding shared network devices via addhardware wizard (rhbz #430926)

* Tue Jan 15 2008 Daniel P. Berrange <berrange@redhat.com> - 0.5.3-1.el5
- Updated to 0.5.3 release (rhbz #428160)

* Mon Jan 7 2008 Cole Robinson <crobinso@redhat.com> - 0.4.0-4.el5
- Rework guest creation to use virtinst for validation (rhbz #324211)

* Tue Jul 24 2007 Hugh O. Brock <hbrock@redhat.com> - 0.4.0-3.el5
- Aggressively free libvirt domain object after it has been deleted. Workaround
  for python's unreliable garbage collection. (rhbz #249094)

* Thu Jul 12 2007 Daniel P. Berrange <berrange@redhat.com> - 0.4.0-2.el5
- Suggest a disk name for file backed VMs (rhbz #216704)

* Thu Jun 14 2007 Daniel P. Berrange <berrange@redhat.com> - 0.4.0-1.el5
- Updated to 0.4.0 release (rhbz #243464, 217596, 215020, 214724)

* Tue Feb 27 2007 Daniel P. Berrange <berrange@redhat.com> - 0.2.6-9.el5
- Implement alternate approach to processing ungrab key sequence

* Fri Feb 23 2007 Daniel P. Berrange <berrange@redhat.com> - 0.2.6-8.el5
- Grab cursor & hide local mouse in console window

* Tue Jan  9 2007 Daniel P. Berrange <berrange@redhat.com> - 0.2.6-7.el5
- Explicitly drop the libvirt virDomainPtr object when a guest shuts down
  to avoid hanging onto objects in libvirt cache (bz 220036)

* Mon Dec 18 2006 Daniel P. Berrange <berrange@redhat.com> - 0.2.6-6.el5
- Imported latest translations from Fedora i18n repository (bz 203783)

* Sun Dec 17 2006 Hugh Brock <hbrock@redhat.com> - 0.2.6-5.el5
- Add selector for sparse or non-sparse file, defaulting to non-sparse. 
  Add appropriate warnings and progress-bar text. (bz 218996)

* Wed Dec 13 2006 Daniel Berrange <berrange@localhost.localdomain> - 0.2.6-4.el5
- Disable memory ballooning & CPU hotplug for HVM guests (bz 214432)

* Tue Dec 12 2006 Hugh Brock <hbrock@redhat.com> - 0.2.6-3.el5
- Updated memory-setting UI to include a hard upper limit for physical 
  host RAM
- Added documentation on the page warning that setting virtual host RAM
  too high can exhaust the memory of the machine

* Mon Dec 11 2006 Daniel Berrange <berrange@localhost.localdomain> - 0.2.6-2.el5
- Imported latest translations from Fedora i18n repository (bz 203783)

* Thu Dec  7 2006 Daniel Berrange <berrange@redhat.com> - 0.2.6-1.el5
- Updated to match 0.2.6-2 release from FC6 tree (bz 218537)
- Handle errors when hostname resolution fails to avoid app exiting
- Make (most) scrollbar policies automatic
- Set busy cursor while creating new VMs
- Preference for controlling keygrab policy
- Added activation of URLs for about dialog
- Improved error reporting when connecting to HV
- Don't skip para/full virt wizard step - instead gray out full
  virt option & tell user why
- Change 'physical' to 'logical' when refering to host CPUs
- Include hostname in titlebar
- Disable wizard sensitivity while creating VM

* Tue Nov 28 2006 Hugh O. Brock <hbrock@redhat.com> - 0.2.5-3.el5
- Add automatic console popups on launching a VM, plus a few console fixes (bz 211385)

* Tue Nov 21 2006 Hugh O. Brock <hbrock@redhat.com> - 0.2.5-2.el5
- Add command-line interface for virt-manager (bz 211553)
- Make virt-manager exit gtk.main when windows opened from the 
  command-line interface are closed (bz 213782)

* Thu Oct 19 2006 Daniel P. Berrange <berrange@redhat.com> - 0.2.5-1.el5
- Switch to use python-virtinst instead of python-xeninst due to 
  renaming of original package
- Disable keyboard accelerators when grabbing mouse to avoid things like
  Ctrl-W closing the local window, instead of remote window bz 210364
- Fix host memory reporting bz 211281
- Remove duplicate application menu entry bz 211230
- Fix duplicated mnemonics (bz 211231)
- Use a drop down list to remember past URLs (bz 211233)
- Remove unused help button from preferences dialog (bz 211232)
- Fix exception when no VNC graphics is defined
- Force immediate refresh of VMs after creating a new one
- Improve error reporting if run on a kernel without Xen (bz 211229)
- More fixes to avoid stuck modifier keys on focus-out (bz 211461)

* Sat Oct  7 2006 Daniel P. Berrange <berrange@redhat.com> 0.2.3-3.el5
- Use blktap based driver for file backed disks by default

* Fri Sep 29 2006 Daniel P. Berrange <berrange@redhat.com> 0.2.3-2.fc6
- Fix segv in sparkline code when no data points are defined (bz  208185)
- Clamp CPU utilization between 0 & 100% just in case (bz 208185)

* Tue Sep 26 2006 Daniel Berrange <berrange@redhat.com> - 0.2.3-1.fc6
- Require xeninst >= 0.93.0 to fix block backed devices
- Skip para/fully-virt step when going back in wizard if not HVM host (bz 207409)
- Fix handling of modifier keys in VNC console so Alt key doesn't get stuck (bz 207949)
- Allow sticky modifier keys by pressing same key 3 times in row (enables Ctrl-Alt-F1
  by doing Ctrl Ctrl Ctrl  Alt-F1)
- Improved error handling during guest creation
- Log errors with python logging, instead of to stdout
- Remove unused buttons from main domain list window
- Switch out of full screen & release key grab when closing console
- Trim sparkline CPU history graph to 40 samples max
- Constraint VCPU adjuster to only allow upto guest's max VCPU count
- Show guest's max & current VCPU count in details page
- Fix rounding of disk sizes to avoid a 1.9 GB disk being rounded down to 1 GB
- Use raw block device path to CDROM not mount point for HVM guest (bz 206965)
- Fix visibility of file size spin box (bz 206186 part 2)
- Check for GTK failing to open X11 display (bz 205938)

* Fri Sep 15 2006 Daniel Berrange <berrange@redhat.com> - 0.2.2-1.fc6
- Fix event handling in create VM wizard (bz 206660 & 206186)
- Fix close button in about dialog (bz 205943)
- Refresh .pot files
- Turn on VNC scrollbars fulltime to avoid GTK window sizing issue
  which consistently resize too small.

* Mon Sep 11 2006 Daniel Berrange <berrange@redhat.com> - 0.2.1-3.fc6
- Added requires on pygtk2-libglade & librsvg2 (bz 205941 & 205942)
- Re-arrange to use console-helper to launch app
- Added 'dist' component to release number

* Wed Sep  6 2006 Jeremy Katz <katzj@redhat.com> - 0.2.1-2
- don't ghost pyo files (#205448)

* Mon Sep  4 2006 Daniel Berrange <berrange@redhat.com> - 0.2.1-1
- Updated to 0.2.1 tar.gz
- Added rules to install/uninstall gconf schemas in preun,post,pre
  scriptlets
- Updated URL for source to reflect new upstream download URL

* Thu Aug 24 2006 Jeremy Katz <katzj@redhat.com> - 0.2.0-3
- BR gettext

* Thu Aug 24 2006 Jeremy Katz <katzj@redhat.com> - 0.2.0-2
- only build on arches with virt

* Tue Aug 22 2006 Daniel Berrange <berrange@redhat.com> - 0.2.0-1
- Added wizard for creating virtual machines
- Added embedded serial console
- Added ability to take screenshots

* Mon Jul 24 2006 Daniel Berrange <berrange@redhat.com> - 0.1.5-2
- Prefix *.pyo files with 'ghost' macro
- Use fully qualified URL in Source  tag

* Thu Jul 20 2006 Daniel Berrange <berrange@redhat.com> - 0.1.5-1
- Update to new 0.1.5 release snapshot

* Thu Jul 20 2006 Daniel Berrange <berrange@redhat.com> - 0.1.4-1
- Update to new 0.1.4 release snapshot

* Mon Jul 17 2006 Daniel Berrange <berrange@redhat.com> - 0.1.3-1
- Fix License tag
- Updated for new release

* Wed Jun 28 2006 Daniel Berrange <berrange@redhat.com> - 0.1.2-3
- Added missing copyright headers on all .py files

* Wed Jun 28 2006 Daniel Berrange <berrange@redhat.com> - 0.1.2-2
- Added python-devel to BuildRequires

* Wed Jun 28 2006 Daniel Berrange <berrange@redhat.com> - 0.1.2-1
- Change URL to public location

* Fri Jun 16 2006 Daniel Berrange <berrange@redhat.com> - 0.1.0-1
- Added initial support for using VNC console

* Thu Apr 20 2006 Daniel Berrange <berrange@redhat.com> - 0.0.2-1
- Added DBus remote control service

* Wed Mar 29 2006 Daniel Berrange <berrange@redhat.com> - 0.0.1-1
- Initial RPM build
